@@ -102,7 +102,7 @@ class MakefileInputs(Base):
 class PACEDB(App):
 
     _name_ = "pacedb"
-    _version_ = "0.1.4"
+    _version_ = "0.1.5"
 
     def __init__(self, mgr):
 
@@ -365,7 +365,7 @@ class PACEDB(App):
 
                 shutil.rmtree(unzipdir, ignore_errors=True)
 
-    def perform(self, mgr, args):
+    def perform(self, args):
 
         self.show_progress = args.progress
         self.verify_db = args.verify
@@ -376,7 +376,7 @@ class PACEDB(App):
         if not args.db_session:
             dbcfg = args.db_cfg["_"]
             if not os.path.isfile(dbcfg):
-                print("Could not find database configuration file: %s" % cbcfg)
+                print("Could not find database configuration file: %s" % dbcfg)
                 sys.exit(-1)
 
             with open(dbcfg) as f:
